//importing from d3
import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

//assigning colors
const sectionColors = [
  		'gold', '#2788bc', 'Pink', 'crimson', 'green', 'slateblue', 'chocolate', 'blue', 'lightgreen', 'aqua'
		  ]; 

//dataset URL
const csvUrl = 'https://gist.githubusercontent.com/rikhitakoganti12/a79c34bebb8ebe025e0115e0c172daf3/raw/e89f71ec74980eef1e60c6ef1453590f139c78dc/mallsdata.csv';

//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

//svh height and width
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

//numbers on the pie chart
const xAxisTickFormat = number =>
  	format('.4~g')(number);

//rendering data on pie chart
const render = (data, total) => {
  const pieData = pie().value(d=>d.ProductsSold)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  //arc
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,220)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.ProductsSold));
  
  //section label
  sections
    .enter()
    .append('text')
    .text(d =>xAxisTickFormat((d.data.ProductsSold)))
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  //legends
  const legends = svg.append("g")
  	.attr("transform", "translate(500,70)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  //legend text
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.ProductsSold));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Malls);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.ProductsSold)));
}

//main function to run the data
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.ProductsSold = +d.ProductsSold;
    total += d.ProductsSold
  });
	render(data,total);
};
run();